@@ -1,4 +1,4 @@
-# version  : 2.04 - November 2020
+# version  : 2.05 - November 2020
 # author   : Thierry LE GALL 
 # contact  : facila@gmx.fr
 
@@ -21,7 +21,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '2.04';
+our $VERSION = '2.05';
 
 my @mask = qw ( 0.0.0.0
 128.0.0.0       192.0.0.0       224.0.0.0       240.0.0.0       248.0.0.0       252.0.0.0       254.0.0.0       255.0.0.0
@@ -279,7 +279,7 @@ sub local_list_1 {
     my($ref_in,$ref_out,$ref_text) = @_;
     my($i,$ip,$mask);
     $i = 0;
-    foreach ( split/;\n/,$$ref_in ) {
+    foreach ( split/;|\n/,$$ref_in ) {
        $ip = $mask = '';
        if    ( /(.+)\/(.+)/ ) { $ip = $1 ; $mask = "/$2"; return 99 if &error('cidr',$2) }
        elsif ( /(.+) (.+)/  ) { $ip = $1 ; $mask = $2 }
@@ -628,7 +628,7 @@ __END__
 
 =head1 VERSION AND AUTHOR
 
- Version  : v2.04 - November 2020
+ Version  : v2.05 - November 2020
  Author   : Thierry LE GALL
  Contact  : facila@gmx.fr
 
